/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_bs extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AUD", "AUD" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "KM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BRL", "BRL" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CAD", "CAD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "CNY", "CNY" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GBP", "GBP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HKD", "HKD" },
            { "HNL", "HNL" },
            { "HRK", "kn" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "ILS", "ILS" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "JPY", "\u00a5" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXN", "MXN" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "NZD", "NZD" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "din." },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "USD", "USD" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "XCD", "XCD" },
            { "XPF", "XPF" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "adp", "Andorska pezeta" },
            { "aed", "Dirham Ujedinjenih Arapskih Emirata" },
            { "afa", "Avganistanski avgani (1927\u20132002)" },
            { "afn", "Afganistanski afgan" },
            { "alk", "Albanski lek (1946\u20131965)" },
            { "all", "Albanski lek" },
            { "amd", "Armenski dram" },
            { "ang", "Holandskoantilski gulden" },
            { "aoa", "Angolska kvanza" },
            { "aok", "Angolijska kvanza (1977\u20131991)" },
            { "aon", "Angolijska nova kvanza (1990\u20132000)" },
            { "aor", "Angolijska kvanza reajustado (1995\u20131999)" },
            { "ara", "Argentinski austral" },
            { "arp", "Argentinski pezo (1983\u20131985)" },
            { "ars", "Argentinski pezos" },
            { "ats", "Austrijski \u0161iling" },
            { "aud", "Australijski dolar" },
            { "awg", "Arubanski florin" },
            { "azm", "Azerbejd\u017eanski manat (1993\u20132006)" },
            { "azn", "Azerbejd\u017eanski manat" },
            { "bad", "Bosansko-Hercegova\u010dki dinar" },
            { "bam", "Bosanskohercegova\u010dka konvertibilna marka" },
            { "bbd", "Barbadoski dolar" },
            { "bdt", "Banglade\u0161ka taka" },
            { "bec", "Belgijski frank (konvertibilni)" },
            { "bef", "Belgijski franak" },
            { "bel", "Belgijski frank (finansijski)" },
            { "bgl", "Bugarski tvrdi lev" },
            { "bgn", "Bugarski lev" },
            { "bgo", "Bugarski lev (1879\u20131952)" },
            { "bhd", "Bahreinski dinar" },
            { "bif", "Burundski franak" },
            { "bmd", "Bermudski dolar" },
            { "bnd", "Brunejski dolar" },
            { "bob", "Bolivijski boliviano" },
            { "bol", "Bolivijski boliviano (1863\u20131963)" },
            { "bop", "Bolivijski pezo" },
            { "bov", "Bolivijski mvdol" },
            { "brb", "Brazilski kruzeiro novo (1967\u20131986)" },
            { "brc", "Brazilski kruzado (1986\u20131989)" },
            { "bre", "Brazilski kruzeiro (1990\u20131993)" },
            { "brl", "Brazilski real" },
            { "brn", "Brazilski kruzado novo (1989\u20131990)" },
            { "brr", "Brazilski kruzeiro (1993\u20131994)" },
            { "brz", "Brazilski kruzeiro (1942\u20131967)" },
            { "bsd", "Bahamski dolar" },
            { "btn", "Butanski ngultrum" },
            { "buk", "Burmanski kjat" },
            { "bwp", "Bocvanska pula" },
            { "byb", "Beloruska nova rublja (1994\u20131999)" },
            { "byn", "Bjeloruska rublja" },
            { "byr", "Bjeloruska rublja (2000\u20132016)" },
            { "bzd", "Belizeanski dolar" },
            { "cad", "Kanadski dolar" },
            { "cdf", "Kongoanski franak" },
            { "che", "WIR Evro" },
            { "chf", "\u0160vicarski franak" },
            { "chw", "WIR franak" },
            { "clf", "\u010cileanski unidades de fomento" },
            { "clp", "\u010cileanski pezos" },
            { "cnh", "Kineski juan (izvanteritorijalni)" },
            { "cny", "Kineski juan" },
            { "cop", "Kolumbijski pezos" },
            { "crc", "Kostarikanski kolon" },
            { "csd", "Srpski dinar (2002\u20132006)" },
            { "csk", "\u010cehoslova\u010dka tvrda koruna" },
            { "cuc", "Kubanski konvertibilni pezos" },
            { "cup", "kubanski pezos" },
            { "cve", "Zelenortski eskudo" },
            { "cyp", "Kipratska funta" },
            { "czk", "\u010ce\u0161ka kruna" },
            { "ddm", "Isto\u010dnoevropska marka" },
            { "dem", "Nema\u010dka marka" },
            { "djf", "D\u017eibutski franak" },
            { "dkk", "Danska kruna" },
            { "dop", "Dominikanski pezos" },
            { "dzd", "Al\u017eirski dinar" },
            { "ecs", "Ekvadorijski sukr" },
            { "ecv", "Ekvadorski unidad de valor konstantin (UVC)" },
            { "eek", "Estonska kruna" },
            { "egp", "Egipatska funta" },
            { "ern", "Eritrejska nakfa" },
            { "esa", "\u0160panska pezeta (ra\u010dun) ESA" },
            { "esb", "\u0160panska pezeta (konvertibilni ra\u010dun)" },
            { "esp", "\u0160panska pezeta" },
            { "etb", "Etiopski bir" },
            { "eur", "Euro" },
            { "fim", "Finska marka" },
            { "fjd", "Fid\u017eijski dolar" },
            { "fkp", "Folklandska funta" },
            { "frf", "Francuski franak" },
            { "gbp", "Britanska funta" },
            { "gek", "Gruzijski kupon larit" },
            { "gel", "Gruzijski lari" },
            { "ghc", "Ganijski cedi (1979\u20132007)" },
            { "ghs", "Ganski cedi" },
            { "gip", "Gibraltarska funta" },
            { "gmd", "Gambijski dalasi" },
            { "gnf", "Gvinejski franak" },
            { "gns", "Gvinejski sili" },
            { "gqe", "Evatorijalna gvineja ekvele" },
            { "grd", "Drahma" },
            { "gtq", "Gvatemalski kecal" },
            { "gwe", "Portugalska Gvineja eskudo" },
            { "gwp", "Gvineja bisao pezo" },
            { "gyd", "Gvajanski dolar" },
            { "hkd", "Honkon\u0161ki dolar" },
            { "hnl", "Hondura\u0161ka lempira" },
            { "hrd", "Hrvatski dinar" },
            { "hrk", "Hrvatska kuna" },
            { "htg", "Hai\u0107anski gurd" },
            { "huf", "Ma\u0111arska forinta" },
            { "idr", "Indone\u017eanska rupija" },
            { "iep", "Irska funta" },
            { "ilp", "Izraelska funta" },
            { "ilr", "stari izraelski \u0161ekeli" },
            { "ils", "Izraelski novi \u0161ekel" },
            { "inr", "Indijska rupija" },
            { "iqd", "Ira\u010dki dinar" },
            { "irr", "Iranski rijal" },
            { "isj", "stara islandska kruna" },
            { "isk", "Islandska kruna" },
            { "itl", "Italijanska lira" },
            { "jmd", "Jamaj\u010danski dolar" },
            { "jod", "Jordanski dinar" },
            { "jpy", "Japanski jen" },
            { "kes", "Kenijski \u0161iling" },
            { "kgs", "Kirgistanski som" },
            { "khr", "Kambod\u017eanski rijel" },
            { "kmf", "Komorski franak" },
            { "kpw", "Sjevernokorejski von" },
            { "krh", "Ju\u017eno-korejski hvan (1953\u20131962)" },
            { "kro", "Ju\u017eno-korejski Von (1945\u20131953)" },
            { "krw", "Ju\u017enokorejski von" },
            { "kwd", "Kuvajtski dinar" },
            { "kyd", "Kajmanski dolar" },
            { "kzt", "Kazahstanski tenge" },
            { "lak", "Laoski kip" },
            { "lbp", "Libanska funta" },
            { "lkr", "\u0160rilankanska rupija" },
            { "lrd", "Liberijski dolar" },
            { "lsl", "Lesotski loti" },
            { "ltl", "Litvanski litas" },
            { "ltt", "Litvanski talonas" },
            { "luc", "Luksembur\u0161ki konvertibilni franak" },
            { "luf", "Luksembur\u0161ki franak" },
            { "lul", "Luksembur\u0161ki finansijski franak" },
            { "lvl", "Letonski lats" },
            { "lvr", "Latvijska rublja" },
            { "lyd", "Libijski dinar" },
            { "mad", "Marokanski dirham" },
            { "maf", "Marokanski franak" },
            { "mdl", "Moldavski lej" },
            { "mga", "Malaga\u0161ki arijari" },
            { "mgf", "Malagasijski franak" },
            { "mkd", "Makedonski denar" },
            { "mkn", "Makedonski denar (1992\u20131993)" },
            { "mlf", "Malijanski franak" },
            { "mmk", "Mijanmarski kjat" },
            { "mnt", "Mongolski tugrik" },
            { "mop", "Makaonska pataka" },
            { "mro", "Mauritanijska ugvija (1973\u20132017)" },
            { "mru", "Mauritanijska ugvija" },
            { "mtl", "Malte\u0161ka lira" },
            { "mtp", "Malte\u0161ka funta" },
            { "mur", "Mauricijska rupija" },
            { "mvr", "Maldivska rufija" },
            { "mwk", "Malavijska kva\u010da" },
            { "mxn", "Meksi\u010dki pezos" },
            { "mxp", "Meksijski srebrno pezo (1861\u20131992)" },
            { "mxv", "Meksijski unidad de inverzion" },
            { "myr", "Malezijski ringit" },
            { "mze", "Mozambijski eskudo" },
            { "mzm", "Mozambijski metikal (1980\u20132006)" },
            { "mzn", "Mozambijski metikal" },
            { "nad", "Namibijski dolar" },
            { "ngn", "Nigerijska naira" },
            { "nic", "Nikaragvan\u0161ka kordoba (1988\u20131991)" },
            { "nio", "Nikaragvanska kordoba" },
            { "nlg", "Holandski gulden" },
            { "nok", "Norve\u0161ka kruna" },
            { "npr", "Nepalska rupija" },
            { "nzd", "Novozelandski dolar" },
            { "omr", "Omanski rijal" },
            { "pab", "Panamska balboa" },
            { "pei", "Peruvijski inti" },
            { "pen", "Peruanski sol" },
            { "pes", "Peruvijski sol (1863\u20131965)" },
            { "pgk", "Kina Papue Nove Gvineje" },
            { "php", "Filipinski pezos" },
            { "pkr", "Pakistanska rupija" },
            { "pln", "Poljski zlot" },
            { "plz", "Poljski zloti (1950\u20131995)" },
            { "pte", "Portugalski eskudo" },
            { "pyg", "Paragvajski gvarani" },
            { "qar", "Katarski rijal" },
            { "rhd", "Rodizijski dolar" },
            { "rol", "Rumunski leu (1952\u20132006)" },
            { "ron", "Rumunski lej" },
            { "rsd", "Srpski dinar" },
            { "rub", "Ruska rublja" },
            { "rur", "Ruska rublja (1991\u20131998)" },
            { "rwf", "Ruandski franak" },
            { "sar", "Saudijski rijal" },
            { "sbd", "Solomonski dolar" },
            { "scr", "Sej\u0161elska rupija" },
            { "sdd", "Sudanski dinar (1992\u20132007)" },
            { "sdg", "Sudanska funta" },
            { "sdp", "Sudanska funta (1957\u20131998)" },
            { "sek", "\u0160vedska kruna" },
            { "sgd", "Singapurski dolar" },
            { "shp", "Svetohelenska funta" },
            { "sit", "Slovenski tolar" },
            { "skk", "Slova\u010dka kruna" },
            { "sll", "Sijeraleonski leone" },
            { "sos", "Somalski \u0161iling" },
            { "srd", "Surinamski dolar" },
            { "srg", "Surinamski gilder" },
            { "ssp", "Ju\u017enosudanska funta" },
            { "std", "Dobra Sao Toma i Principa (1977\u20132017)" },
            { "stn", "Dobra Sao Toma i Principa" },
            { "sur", "Sovjetska rublja" },
            { "svc", "Salvadorski kolon" },
            { "syp", "Sirijska funta" },
            { "szl", "Svazilendski lilangeni" },
            { "thb", "Tajlandski baht" },
            { "tjr", "Tad\u017eakistanska rublja" },
            { "tjs", "Tad\u017eikistanski somoni" },
            { "tmm", "Turkmenistanski manat (1993\u20132009)" },
            { "tmt", "Turkmenistanski manat" },
            { "tnd", "Tuni\u0161ki dinar" },
            { "top", "Tonganska panga" },
            { "tpe", "Timor\u0161ki eskudo" },
            { "trl", "Turska lira (1922\u20132005)" },
            { "try", "Turska lira" },
            { "ttd", "Trinidadtoba\u0161ki dolar" },
            { "twd", "Novi tajvanski dolar" },
            { "tzs", "Tanzanijski \u0161iling" },
            { "uah", "Ukrajinska hrivnja" },
            { "uak", "Ukrajinski karbovaneti" },
            { "ugs", "Ugandijski \u0161iling (1966\u20131987)" },
            { "ugx", "Ugandski \u0161iling" },
            { "usd", "Ameri\u010dki dolar" },
            { "usn", "SAD dolar (slede\u0107i dan)" },
            { "uss", "SAD dolar (isti dan)" },
            { "uyi", "Urugvajski pezo en unidades indeksades" },
            { "uyp", "Urugvajski pezo (1975\u20131993)" },
            { "uyu", "Urugvajski pezos" },
            { "uzs", "Uzbekistanski som" },
            { "veb", "Venecuelanski bolivar (1871\u20132008)" },
            { "vef", "venecuelanski bolivar (2008\u20132018)" },
            { "ves", "Venecuelanski bolivar" },
            { "vnd", "Vijetnamski dong" },
            { "vnn", "Vijetnamski dong (1978\u20131985)" },
            { "vuv", "Vanuatski vatu" },
            { "wst", "Samoanska tala" },
            { "xaf", "Centralnoafri\u010dki franak (CFA)" },
            { "xag", "Srebro" },
            { "xau", "Zlato" },
            { "xba", "Evropska kompozitna jedinica" },
            { "xbb", "Evropska nov\u010dana jedinica" },
            { "xbc", "Evropska jedinica ra\u010duna (XBC)" },
            { "xbd", "Evropska jedinica ra\u010duna (XBD)" },
            { "xcd", "Isto\u010dnokaripski dolar" },
            { "xdr", "Posebna prava" },
            { "xeu", "Evropska valutna jedinica" },
            { "xfo", "Francuski zlatni frank" },
            { "xfu", "Francuski UIC-frank" },
            { "xof", "Zapadnoafri\u010dki franak (CFA)" },
            { "xpd", "Paladijum" },
            { "xpf", "Franak (CFP)" },
            { "xpt", "Platina" },
            { "xre", "RINET fondovi" },
            { "xts", "Kod testirane valute" },
            { "xxx", "Nepoznata valuta" },
            { "ydd", "Jemenski dinar" },
            { "yer", "Jemenski rijal" },
            { "yud", "Jugoslovenski tvrdi dinar" },
            { "yum", "Jugoslovenski novi dinar" },
            { "yun", "Jugoslovenski konvertibilni dinar" },
            { "zal", "Ju\u017enoafri\u010dki rand (finansijski)" },
            { "zar", "Ju\u017enoafri\u010dki rand" },
            { "zmk", "Zambijska kva\u010da (1968\u20132012)" },
            { "zmw", "Zambijska kva\u010da" },
            { "zrn", "Zairski novi zair (1993\u20131998)" },
            { "zrz", "Zairski zair (1971\u20131993)" },
            { "zwd", "Zimbabvejski dolar (1980\u20132008)" },
            { "zwl", "Zimbabvejski dolar (2009)" },
            { "zwr", "Zimbabvejski dolar (2008)" },
        };
        return data;
    }
}
